@@ -2,6 +2,7 @@ import timeit
 import warnings
 import pandas as pd
 
+from math import ceil
 from psutil import cpu_count
 from dask import dataframe as dd
 
@@ -25,7 +26,7 @@ class _SwifterObject:
     ):
         self._obj = pandas_obj
         self._nrows = self._obj.shape[0]
-        self._SAMP_SIZE = SAMP_SIZE if self._nrows > 25000 else int(round(self._nrows / 25))
+        self._SAMP_SIZE = SAMP_SIZE if self._nrows > 25000 else int(ceil(self._nrows / 25))
 
         if npartitions is None:
             self._npartitions = cpu_count() * 2
@@ -143,7 +144,7 @@ class SeriesAccessor(_SwifterObject):
         """
         samp = self._obj.iloc[: self._npartitions * 2]
         # check if input is string or if the user is overriding the string processing default
-        str_processing = (samp.dtype == "object") if not self._allow_dask_on_strings else False
+        allow_dask_processing = True if self._allow_dask_on_strings else (samp.dtype != "object")
 
         if "axis" in kwds.keys():
             kwds.pop("axis")
@@ -167,7 +168,7 @@ class SeriesAccessor(_SwifterObject):
             est_apply_duration = samp_proc_est / self._SAMP_SIZE * self._obj.shape[0]
 
             # if pandas apply takes too long and not performing str processing, use dask
-            if (est_apply_duration > self._dask_threshold) and (not str_processing):
+            if (est_apply_duration > self._dask_threshold) and allow_dask_processing:
                 return self._dask_apply(func, convert_dtype, *args, **kwds)
             else:  # use pandas
                 if self._progress_bar:
@@ -248,7 +249,7 @@ class DataFrameAccessor(_SwifterObject):
         """
         samp = self._obj.iloc[: self._npartitions * 2, :]
         # check if input is string or if the user is overriding the string processing default
-        str_processing = ("object" in samp.dtypes.values) if not self._allow_dask_on_strings else False
+        allow_dask_processing = True if self._allow_dask_on_strings else ("object" not in samp.dtypes.values)
 
         try:  # try to vectorize
             tmp_df = func(samp, *args, **kwds)
@@ -272,7 +273,7 @@ class DataFrameAccessor(_SwifterObject):
             est_apply_duration = samp_proc_est / self._SAMP_SIZE * self._obj.shape[0]
 
             # if pandas apply takes too long and not performing str processing, use dask
-            if (est_apply_duration > self._dask_threshold) and (not str_processing):
+            if (est_apply_duration > self._dask_threshold) and allow_dask_processing:
                 if axis == 0:
                     raise NotImplementedError(
                         "Swifter cannot perform axis=0 applies on large datasets.\n"
